## Overview

This directory contains helper utilities that are not ideally set up for use in a aces module, but provide potentially useful functionality. In time they may be merged into something that is installed alongside the other package submodules. 
